| Title: | An App that Assists Intro Statistics Instructors with Data Sets |
|---|---|
| Description: | Includes an interactive application designed to support educators in wide-ranging disciplines, with a particular focus on those teaching introductory statistical methods (descriptive and/or inferential) for data analysis. Users are able to randomly generate data, make new versions of existing data through common adjustments (e.g., add random normal noise and perform transformations), and check the suitability of the resulting data for statistical analyses. |
| Authors: | Christopher Casement [cre, aut], Laura McSweeney [aut] |
| Maintainer: | Christopher Casement <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.3 |
| Built: | 2026-05-18 06:22:06 UTC |
| Source: | https://github.com/ccasement/statteacherassistant |
Includes an interactive application designed to support educators in wide-ranging disciplines, with a particular focus on those teaching introductory statistical methods (descriptive and/or inferential) for data analysis. Users are able to randomly generate data, make new versions of existing data through common adjustments (e.g., add random normal noise and perform transformations), and check the suitability of the resulting data for statistical analyses.
Package: StatTeacherAssistant
Type: Package
Version: 0.0.3
Date: 2025-05-01
Depends: R (>= 3.5.0)
Imports: DescTools, dplyr, DT, extraDistr, ggplot2, plotly, rhandsontable,
rio, rmatio, shiny, shinyalert, shinyBS, shinyjs, sortable, stringi, stringr,
tidyr
License: MIT
BugReports: https://github.com/ccasement/StatTeacherAssistant/issues
Encoding: UTF-8
Christopher Casement
Department of Mathematics
Fairfield University
[email protected]
Laura McSweeney
Department of Mathematics
Fairfield University
Useful links:
Report bugs at https://github.com/ccasement/StatTeacherAssistant/issues
Runs the StatTeacherAssistant Shiny application.
runStatTeacherAssistantApp()runStatTeacherAssistantApp()
There is no return value.
Christopher Casement
Department of Mathematics
Fairfield University
[email protected]
Laura McSweeney
Department of Mathematics
Fairfield University
## only run the app in an interactive R session if (interactive()) {runStatTeacherAssistantApp()}## only run the app in an interactive R session if (interactive()) {runStatTeacherAssistantApp()}